@@ -2,7 +2,7 @@ package Pcore::API::Whois::Response;
 
 use Pcore -class, -const, -export => { CONST => [qw[$WHOIS_FOUND $WHOIS_NOT_FOUND $WHOIS_NETWORK_ERROR $WHOIS_NO_CONTENT $WHOIS_BANNED $WHOIS_UNKNOWN $WHOIS_NOT_SUPPORTED]] };
 
-with qw[Pcore::Util::Status::Role];
+with qw[Pcore::Util::Result::Status];
 
 has query => ( is => 'ro', isa => Str, required => 1 );
 
